/* daemonitor/src/daemonitor/999_main.c
 *
 *  (c)2007, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv3. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



/* usage()
 *  Display the usage info.
 */
void usage(void)
{
    fputs("Usage:\n\n"
        "    daemonitor [options] -- /path/to/program [args]\n\n"
        "Valid options:\n"
        " -h, --help                Display this screen.\n"
        " -V, --version             Display version number.\n"
        " -l, --log <dest>          Log file destination, may be one of:\n"
        "                               SYSLOG - log to syslog (default)\n"
        "                               STDOUT - log to stdout\n"
        "                               STDERR - log to stderr\n"
        "                               file path - log to file\n"
    "", stderr);
}



/* options[]
 *  The array of long commandline options for getopt(3).
 */
struct option options[] = {
    { "help", no_argument, 0, 'h' },
    { "version", no_argument, 0, 'V' },
    { "log", required_argument, 0, 'l' },
    { 0, 0, 0, 0 }
};



/* optstr
 *  The list of short commandline options for getopt(3). Sorted alphabetically, lowercase first.
 */
const char* optstr = "hl:V";



/* main()
 *  The program driver. Parses the commandline options, sets up the environment, and starts the
 *  daemon monitoring process.
 */
int main(int argc, char* argv[])
{
    const char* log_argument = 0;

    while(1) {
        switch(getopt_long(argc, argv, optstr, options, 0)) {
        case -1: goto opts_done;
        case '?': LOG_ANYWHERE("Invalid commandline options."); return 1;
        case 'h': usage(); return 1;
        case 'V': fputs("daemonitor " VERSION "\n", stderr); return 1;
        case 'l': log_argument = optarg; break;
        }
    }
  opts_done:
    /* set up logging */
    if(!log_argument || !strcmp(log_argument, "SYSLOG")) {
        log_destination_set(log_destination_syslog);
    } else if(!strcmp(log_argument, "STDOUT")) {
        log_destination_set(log_destination_stdout);
    } else if(!strcmp(log_argument, "STDERR")) {
        log_destination_set(log_destination_stderr);
    } else {
        if(log_destination_set_file(log_argument)) {
            LOG_ANYWHERE("Error logging to file `%s' (%m).", log_argument);
            return 1;
        }
    }

    return 0;
}



/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
